import 'package:sghi_core/app_wrapper/enums.dart';

/// A configuration class for an application that holds variant and environment settings.
///
/// This class is designed to be immutable and provides functionality to compare instances
/// based on the variant and environment values.
class AppConfig {
  /// Constructs an immutable configuration with the required properties.
  ///
  /// [variant] specifies the variant of the application, such as debug or release.
  /// [environment] specifies the environment of the application, such as production or test.
  const AppConfig({required this.variant, required this.environment});

  /// The variant of the application.
  ///
  /// This field is used to identify the specific build variant (e.g., debug, release).
  final AppVariant variant;

  /// The environment in which the application is running.
  ///
  /// This field can indicate environments like production, development, or test.
  final AppEnvironment environment;

  @override
  bool operator ==(Object other) =>

      /// Overrides the equality operator to compare AppConfig instances.
      ///
      /// Returns true if [other] is an instance of [AppConfig] and if [variant] and
      /// [environment] of both instances are equal.
      other is AppConfig &&
      other.variant == variant &&
      other.environment == environment;

  @override
  int get hashCode =>

      /// Provides a hash code for an AppConfig instance.
      ///
      /// Combines the hash codes of [variant] and [environment] to generate a unique hash code
      /// for each unique combination of [variant] and [environment].
      Object.hash(variant, environment);
}

// Instances for BEWELL variant
AppConfig bewellTest = const AppConfig(
    variant: AppVariant.BEWELL, environment: AppEnvironment.TEST);
AppConfig bewellDemo = const AppConfig(
    variant: AppVariant.BEWELL, environment: AppEnvironment.DEMO);
AppConfig bewellProd = const AppConfig(
    variant: AppVariant.BEWELL, environment: AppEnvironment.PROD);
AppConfig bewellE2E = const AppConfig(
    variant: AppVariant.BEWELL, environment: AppEnvironment.E2E);

// Instances for SLADE360ADVANTAGE variant
AppConfig slade360AdvantageTest = const AppConfig(
    variant: AppVariant.SLADE360ADVANTAGE, environment: AppEnvironment.TEST);
AppConfig slade360AdvantageDemo = const AppConfig(
    variant: AppVariant.SLADE360ADVANTAGE, environment: AppEnvironment.DEMO);
AppConfig slade360AdvantageProd = const AppConfig(
    variant: AppVariant.SLADE360ADVANTAGE, environment: AppEnvironment.PROD);
AppConfig slade360AdvantageE2E = const AppConfig(
    variant: AppVariant.SLADE360ADVANTAGE, environment: AppEnvironment.E2E);

// Instances for MYCAREHUB variant
AppConfig myCareHubTest = const AppConfig(
    variant: AppVariant.MYCAREHUB, environment: AppEnvironment.TEST);
AppConfig myCareHubDemo = const AppConfig(
    variant: AppVariant.MYCAREHUB, environment: AppEnvironment.DEMO);
AppConfig myCareHubProd = const AppConfig(
    variant: AppVariant.MYCAREHUB, environment: AppEnvironment.PROD);
AppConfig myCareHubE2E = const AppConfig(
    variant: AppVariant.MYCAREHUB, environment: AppEnvironment.E2E);

// Instances for MYCAREHUBDAKTARI variant
AppConfig myCareHubDaktariTest = const AppConfig(
    variant: AppVariant.MYCAREHUBDAKTARI, environment: AppEnvironment.TEST);
AppConfig myCareHubDaktariDemo = const AppConfig(
    variant: AppVariant.MYCAREHUBDAKTARI, environment: AppEnvironment.DEMO);
AppConfig myCareHubDaktariProd = const AppConfig(
    variant: AppVariant.MYCAREHUBDAKTARI, environment: AppEnvironment.PROD);
AppConfig myCareHubDaktariE2E = const AppConfig(
    variant: AppVariant.MYCAREHUBDAKTARI, environment: AppEnvironment.E2E);

// Instances for UONAFYAPP360 variant
AppConfig uonAfyaApp360Test = const AppConfig(
    variant: AppVariant.UONAFYAPP360, environment: AppEnvironment.TEST);
AppConfig uonAfyaApp360Demo = const AppConfig(
    variant: AppVariant.UONAFYAPP360, environment: AppEnvironment.DEMO);
AppConfig uonAfyaApp360Prod = const AppConfig(
    variant: AppVariant.UONAFYAPP360, environment: AppEnvironment.PROD);
AppConfig uonAfyaApp360E2E = const AppConfig(
    variant: AppVariant.UONAFYAPP360, environment: AppEnvironment.E2E);

// Instances for UONAFYAPP360DAKTARI variant
AppConfig uonAfyaApp360DaktariTest = const AppConfig(
    variant: AppVariant.UONAFYAPP360DAKTARI, environment: AppEnvironment.TEST);
AppConfig uonAfyaApp360DaktariDemo = const AppConfig(
    variant: AppVariant.UONAFYAPP360DAKTARI, environment: AppEnvironment.DEMO);
AppConfig uonAfyaApp360DaktariProd = const AppConfig(
    variant: AppVariant.UONAFYAPP360DAKTARI, environment: AppEnvironment.PROD);
AppConfig uonAfyaApp360DaktariE2E = const AppConfig(
    variant: AppVariant.UONAFYAPP360DAKTARI, environment: AppEnvironment.E2E);
