import 'package:flutter/material.dart';
import 'package:sghi_core/app_wrapper/app_config.dart';

import 'package:sghi_core/app_wrapper/app_wrapper_base.dart';
import 'package:sghi_core/app_wrapper/base_context.dart';
import 'package:sghi_core/app_wrapper/device_capabilities.dart';
import 'package:sghi_core/flutter_graphql_client/i_custom_graphql_client.dart';
import 'package:sghi_core/flutter_graphql_client/i_flutter_graphql_client.dart';
import 'package:sghi_core/misc_utilities/authserver_api_client.dart';

/// [AppWrapper] Is a top level Class used to wrap your application.
///
/// @params
/// - `child` the widget that will be wrapped by this wrapper
/// - `appName` A required string that identifies your application
/// - `graphQLClient` An instance of [IGraphQlClient] which is the '
/// 'blueprint of a valid GraphQL client.
/// - `appConfig` [context] app running environments.
/// - `eventBus` Used to log events
class AppWrapper extends StatefulWidget {
  const AppWrapper({
    required this.child,
    required this.appName,
    required this.graphQLClient,
    this.communitiesClient,
    required this.appConfig,
    this.authServerAPIClient,
    this.eventBus,
    this.baseContext,
    this.mediaServerUrl,
    this.iCustomGraphQlClient,
  });

  /// [child] the widget that will be wrapped by this wrapper
  final Widget child;

  /// [appName] the name of the app
  final String appName;

  /// Used to send events to the backend
  final dynamic eventBus;

  /// [graphQLClient] is the graphql client from flutter_graphql_client package
  /// it is dynamic to avoid cyclic-dependency errors when packages
  /// cross depend on each other
  final IGraphQlClient graphQLClient;

  /// [iCustomGraphQlClient] is a custom graphql client from flutter_graphql_client package
  final ICustomGraphQlClient? iCustomGraphQlClient;

  /// [communitiesClient] a copy of [graphQLClient] used to make communities related API calls
  final IGraphQlClient? communitiesClient;

  /// [communitiesClient] is the client used to make authentication call with authServer
  final AuthServerAPIClient? authServerAPIClient;

  /// Represents the configuration of the app, including its variant and environment.
  /// [appConfig] specifies the app's running environment and variant configuration.
  /// This encapsulates different app `variants` (e.g., BEWELL, MYCAREHUB) and their respective
  /// environments (e.g., `prod`, `test`, `demo`, `e2e`).
  ///
  /// An app's configuration is uniquely determined by a combination of its variant and environment,
  /// which is crucial for defining behavior, features availability, and API endpoints specific to each setup.
  final AppConfig appConfig;

  final BaseContext? baseContext;

  final String? mediaServerUrl;

  @override
  AppWrapperState createState() => AppWrapperState();
}

class AppWrapperState extends State<AppWrapper> {
  @override
  void initState() {
    super.initState();
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return LayoutBuilder(
      key: const Key('sil_app_wrapper'),
      builder: (BuildContext context, BoxConstraints boxConstraints) {
        return AppWrapperBase(
          appName: widget.appName,
          eventBus: widget.eventBus,
          authServerAPIClient: widget.authServerAPIClient,
          graphQLClient: widget.graphQLClient,
          iCustomGraphQlClient: widget.iCustomGraphQlClient,
          communitiesClient: widget.communitiesClient,
          appConfig: widget.appConfig,
          deviceCapabilities: DeviceCapabilities(),
          customContext: widget.baseContext,
          mediaServerUrl: widget.mediaServerUrl,
          child: widget.child,
        );
      },
    );
  }
}
